@@ -21,7 +21,6 @@
 #include "DHCPScanner.h"
 #include "PacketMaker.h"
 #include "Environment.h"
-#include "NetBuffer.h"
 
 #include <netinet/in.h> // ntohs, htons, ...
 
@@ -32,6 +31,7 @@ extern "C" {
 */
 
 using namespace std;
+using namespace wibble::sys;
 
 
 void DHCPScanner::handleDHCP(const NetBuffer& dhcp) throw ()
