@@ -23,7 +23,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "Mutex.h"
+#include <wibble/sys/mutex.h>
 #include "Scanner.h"
 #include "NetWatcher.h"
 #include "NetSender.h"
@@ -34,7 +34,7 @@
 class DHCPScanner : public Scanner, public PacketListener
 {
 protected:
-	Mutex candMutex;
+	wibble::sys::Mutex candMutex;
 
 	NetSender sender;
 
@@ -45,7 +45,7 @@ public:
 		: Scanner(listener), sender(sender) {}
 	virtual ~DHCPScanner() throw () {}
 
-	virtual void handleDHCP(const NetBuffer& dhcp) throw ();
+	virtual void handleDHCP(const wibble::sys::NetBuffer& dhcp) throw ();
 	
 	void addCandidate(const DHCPScan* scan) throw ();
 };
