@@ -28,17 +28,62 @@
 #endif
 
 #include "GuessnetEnvironment.h"
-#include "CommandlineParser.h"
-#include "Regexp.h"
 
 #include "GuessnetParser.h"
 #include "IfaceParser.h"
 
+#include <wibble/regexp.h>
+#include <wibble/commandline/parser.h>
 #include <set>
 
 #include <stdio.h>
 #include <stdarg.h>
 
+namespace wibble {
+namespace commandline {
+
+struct GuessnetOptions : public StandardParserWithManpage
+{
+public:
+	BoolOption* verbose;
+	BoolOption* debug;
+	BoolOption* ifupdown;
+	StringOption* defprof;
+	IntOption* timeout;
+	IntOption* inittime;
+	ExistingFileOption* configfile;
+
+	GuessnetOptions() 
+		: StandardParserWithManpage(APPNAME, VERSION, 8, "enrico@enricozini.org")
+	{
+		usage = "[options] [iface]";
+		description = "Guess the current network location";
+
+		verbose = add<BoolOption>("verbose", 'v', "verbose", "",
+						"enable verbose output");
+		debug = add<BoolOption>("debug", 0, "debug", "",
+						"enable debugging output (including verbose output)");
+		configfile = add<ExistingFileOption>("configfile", 'C', "config-file", "",
+						"name of the configuration file to read (default: stdin or"
+						"/etc/network/interfaces in ifupdown mode");
+		ifupdown = add<BoolOption>("ifupdown", 'i', "ifupdown-mode", "",
+						"use /etc/network/interfaces file instead of the usual"
+						" guessnet configuration file");
+		defprof = add<StringOption>("defprof", 'd', "default", "name",
+						"profile name to report if no known networks are found"
+						" (defaults to \"none\")");
+		timeout = add<IntOption>("timeout", 't', "timeout", "seconds",
+						"timeout (in seconds) used to wait for response packets"
+						" (defaults to 5 seconds)");
+		inittime = add<IntOption>("inittime", 0, "init-timeout", "seconds",
+						"time (in seconds) to wait for the interface to initialize"
+						" when not found already up (defaults to 3 seconds)");
+	}
+};
+
+}
+}
+
 using namespace std;
 
 static GuessnetEnvironment* instance;
@@ -55,40 +100,38 @@ protected:
 	string configFile;
 
 public:
-	StandaloneEnvironment(CommandlineParser& opts)
+	StandaloneEnvironment(wibble::commandline::GuessnetOptions& opts)
 	{
-		// Find out the configuration file to use
-		if (opts.get_argc() > 2)
-			configFile = opts.get_argv()[2];
-		else if (opts.get("configfile").defined())
-			configFile = opts.get("configfile").stringVal();
-
 		// Set verbosity
-		verbose(opts.get("verbose").defined());
-		debug(opts.get("debug").defined());
-
+		verbose(opts.verbose->boolValue());
+		debug(opts.debug->boolValue());
 
 		// Find out the interface to be tested
-		if (opts.get_argc() > 1)
-			iface(opts.get_argv()[1]);
+		if (opts.hasNext())
+			iface(opts.next());
 		else
 			iface("eth0");
 
+		// Find out the configuration file to use
+		if (opts.hasNext())
+			configFile = opts.next();
+		else if (opts.configfile->boolValue())
+			configFile = opts.configfile->stringValue();
 
 		// Find out the default profile name
-		if (opts.get("defprof").defined())
+		if (opts.defprof->boolValue())
 		{
-			defprof(opts.get("defprof").stringVal());
-			::verbose("Default profile set to `%.*s'\n", PFSTR(defprof()));
+			defprof(opts.defprof->stringValue());
+			::verbose("Default profile set to `%s'\n", defprof().c_str());
 		}
 
 		// Find out the test timeout
-		if (opts.get("timeout").defined())
-			timeout(opts.get("timeout").intVal());
+		if (opts.timeout->boolValue())
+			timeout(opts.timeout->intValue());
 
 		// Find out the init timeout
-		if (opts.get("inittime").defined())
-			initTimeout(opts.get("inittime").intVal());
+		if (opts.inittime->boolValue())
+			initTimeout(opts.inittime->intValue());
 
 	}
 
@@ -110,7 +153,7 @@ void StandaloneEnvironment::parseConfigFile()
 	{
 		input = fopen(configFile.c_str(), "rt");
 		if (!input)
-			throw FileException(errno, "opening " + configFile);
+			throw wibble::exception::File(configFile, "opening file");
 	}
 
 	GuessnetParser::parse(input, *this);
@@ -151,10 +194,11 @@ class IfupdownEnvironment : public StandaloneEnvironment
 {
 protected:
 	set<string> ifupdownProfiles;
+	bool ifupdownProfilesMatchInverted;
 
 public:
-	IfupdownEnvironment(CommandlineParser& opt) :
-		StandaloneEnvironment(opt)
+	IfupdownEnvironment(wibble::commandline::GuessnetOptions& opt) :
+		StandaloneEnvironment(opt), ifupdownProfilesMatchInverted(false)
 	{
 		// We have a default config file name in ifupdown mode
 		if (configFile.empty())
@@ -163,9 +207,8 @@ public:
 		::debug("program name is guessnet-ifupdown: enabling ifupdown mode\n");
 
 		// Read stuff from stdin
-		ExtendedRegexp null_line("^[[:blank:]]*(#.*)?$");
-		ExtendedRegexp parm_line(
-				"^[[:blank:]]*([A-Za-z_-]+):[[:blank:]]*(.+)$", 3);
+		wibble::ERegexp null_line("^[[:blank:]]*(#.*)?$");
+		wibble::ERegexp parm_line("^[[:blank:]]*([A-Za-z_-]+):[[:blank:]]*(.+)$", 3);
 
 		string line;
 		int linenum = 1;
@@ -217,8 +260,29 @@ public:
 				else
 				{
 					Tokenizer t(line);
+					bool first = true;
 					for (string w = t.next(); !w.empty(); w = t.next())
-						ifupdownProfiles.insert(w);
+					{
+						if (first)
+						{
+							ifupdownProfilesMatchInverted = w[0] == '!';
+							first = false;
+						}
+						if (w[0] == '!')
+						{
+							if (!ifupdownProfilesMatchInverted)
+								throw wibble::exception::Consistency(
+										"parsing list of interfaces to use",
+										"found negated interface "+w+" after a normal interface");
+							ifupdownProfiles.insert(w.substr(1));
+						} else {
+							if (ifupdownProfilesMatchInverted)
+								throw wibble::exception::Consistency(
+										"parsing list of interfaces to use",
+										"found normal interface "+w+" after negated interface");
+							ifupdownProfiles.insert(w);
+						}
+					}
 				}
 				line = string();
 				linenum++;
@@ -232,7 +296,11 @@ public:
 
 void IfupdownEnvironment::handleScan(const Scan* scan) throw ()
 {
-	if (ifupdownProfiles.size() == 0 || ifupdownProfiles.find(scan->name()) != ifupdownProfiles.end())
+	if (ifupdownProfiles.size() == 0)
+		_scans.push_back(scan);
+	else if (ifupdownProfilesMatchInverted && ifupdownProfiles.find(scan->name()) == ifupdownProfiles.end())
+		_scans.push_back(scan);
+	else if (!ifupdownProfilesMatchInverted && ifupdownProfiles.find(scan->name()) != ifupdownProfiles.end())
 		_scans.push_back(scan);
 }
 
@@ -241,7 +309,7 @@ void IfupdownEnvironment::parseConfigFile()
 	/* Open the specified config file or stdin if not specified */
 	FILE* input = fopen(configFile.c_str(), "rt");;
 	if (!input)
-		throw FileException(errno, "opening " + configFile);
+		throw wibble::exception::File(configFile, "opening file");
 
 	IfaceParser::parse(input, *this);
 
@@ -250,44 +318,10 @@ void IfupdownEnvironment::parseConfigFile()
 
 void GuessnetEnvironment::init(int argc, const char* argv[])
 {
-	CommandlineParser opts(APPNAME, "[options] [ethernet_interface]", "Guess the current network location");
-	opts.add("version", 'V', "version", "print the program version, then exit");
-	opts.add("configfile", 'C', "config-file",
-			"name of the configuration file to read (default: stdin or"
-			"/etc/network/interfaces in ifupdown mode", "file");
-	opts.add("ifupdown", 'i', "ifupdown-mode",
-			"use /etc/network/interfaces file instead of the usual"
-			" guessnet configuration file");
-	opts.add("defprof", 'd', "default",
-			"profile name to report if no known networks are found"
-			" (defaults to \"none\")", "name");
-	opts.add("timeout", 't', "timeout",
-			"timeout (in seconds) used to wait for response packets"
-			" (defaults to 5 seconds)", "seconds");
-	opts.add("inittime", 0, "init-timeout",
-			"time (in seconds) to wait for the interface to initialize"
-			" when not found already up (defaults to 3 seconds)");
-	opts.add("verbose", 'v', "verbose",
-			"enable verbose operations");
-	opts.add("debug", 0, "debug", 
-			"enable debugging output");
+	wibble::commandline::GuessnetOptions opts;
 
-	// Process the commandline
-	if (!opts.parse(argc, argv))
-	{
-		opts.printHelp();
-		exit(1);
-	}
-	if (opts.get("help").defined())
-	{
-		opts.printHelp();
+	if (opts.parse(argc, (const char**)argv))
 		exit(0);
-	}
-	if (opts.get("version").defined())
-	{
-		printf("%s " VERSION "\n", APPNAME);
-		exit(0);
-	}
 
 	// Check user id
 	/*
@@ -295,9 +329,8 @@ void GuessnetEnvironment::init(int argc, const char* argv[])
 		fatal_error("You must run this command as root.");
 	*/
 
-
 	// Find out wether we should run in ifupdown mode
-	bool ifupdown_mode = opts.get("ifupdown").defined();
+	bool ifupdown_mode = opts.ifupdown->boolValue();
 	if (!ifupdown_mode)
 	{
 		const char* pname = strrchr(argv[0], '/');
