@@ -28,25 +28,23 @@
 #endif
 
 #include "GuessnetParser.h"
-#include "stringf.h"
-#include "Regexp.h"
+#include <wibble/regexp.h>
 #include "Environment.h"
 
 #include <string>
 
 using namespace std;
-using namespace stringf;
 
 /* Parse the input from `input'
  * To make it simple, use regexps on input lines instead of implementing a real
  * parser.
  */
-void GuessnetParser::parse(FILE* input, ScanConsumer& sc) throw (Exception)
+void GuessnetParser::parse(FILE* input, ScanConsumer& sc)
 {
 #define MACPATTERN "[0-9A-Fa-f]{2}:[0-9A-Fa-f]{2}:[0-9A-Fa-f]{2}:[0-9A-Fa-f]{2}:[0-9A-Fa-f]{2}:[0-9A-Fa-f]{2}"
 #define IPPATTERN "[0-9]+\\.[0-9]+\\.[0-9]+\\.[0-9]+"
-	ExtendedRegexp null_line("^[[:blank:]]*(#.*)?$");
-	ExtendedRegexp peer_line(
+	wibble::ERegexp null_line("^[[:blank:]]*(#.*)?$");
+	wibble::ERegexp peer_line(
 		"^[[:blank:]]*"
 		"([^[:blank:]]+)[[:blank:]]+"
 		"peer[[:blank:]]+"
@@ -54,35 +52,35 @@ void GuessnetParser::parse(FILE* input, ScanConsumer& sc) throw (Exception)
 		"([[:blank:]]+(" MACPATTERN "))?"
 		"([[:blank:]]+(" IPPATTERN "))?"
 		"[[:blank:]]*$", 7);
-	ExtendedRegexp cable_line(
+	wibble::ERegexp cable_line(
 		"^[[:blank:]]*"
 		"([^[:blank:]]+)[[:blank:]]+"
 		"missing-cable[[:blank:]]*$", 2);
-	ExtendedRegexp script_line(
+	wibble::ERegexp script_line(
 		"^[[:blank:]]*"
 		"([^[:blank:]]+)[[:blank:]]+"
-		"(script|command)[[:blank:]]+(.+)$", 3);
-	ExtendedRegexp dhcp_line(
+		"(script|command)[[:blank:]]+(.+)$", 4);
+	wibble::ERegexp dhcp_line(
 		"^[[:blank:]]*"
 		"([^[:blank:]]+)[[:blank:]]+"
 		"dhcp[[:blank:]]*$", 2);
-	ExtendedRegexp pppoe_line(
+	wibble::ERegexp pppoe_line(
 		"^[[:blank:]]*"
 		"([^[:blank:]]+)[[:blank:]]+"
 		"pppoe[[:blank:]]*$", 2);
-	ExtendedRegexp wireless_mac_essid_line(
+	wibble::ERegexp wireless_mac_essid_line(
 		"^[[:blank:]]*"
 		"([^[:blank:]]+)[[:blank:]]+"
 		"wireless[[:blank:]]+mac[[:blank:]]+([^[:blank:]]+)[[:blank:]]+essid[[:blank:]](.+)$", 4);
-	ExtendedRegexp wireless_mac_line(
+	wibble::ERegexp wireless_mac_line(
 		"^[[:blank:]]*"
 		"([^[:blank:]]+)[[:blank:]]+"
 		"wireless[[:blank:]]+mac[[:blank:]]+([^[:blank:]]+)[[:blank:]]*$", 3);
-	ExtendedRegexp wireless_essid_line(
+	wibble::ERegexp wireless_essid_line(
 		"^[[:blank:]]*"
 		"([^[:blank:]]+)[[:blank:]]+"
 		"wireless[[:blank:]]+essid[[:blank:]](.+)$", 3);
-	ExtendedRegexp old_input_line(
+	wibble::ERegexp old_input_line(
 		"^[[:blank:]]*(" IPPATTERN ")[[:blank:]]+"
 		"(" MACPATTERN ")"
 		"[[:blank:]]+(" IPPATTERN ")[[:blank:]]+([[:alnum:]_+-]+)"
@@ -152,7 +150,7 @@ void GuessnetParser::parse(FILE* input, ScanConsumer& sc) throw (Exception)
 			else if (script_line.match(line))
 			{
 				string name = script_line[1];
-				string cmd = script_line[2];
+				string cmd = script_line[3];
 				//fprintf(stderr, "TEST: %.*s\n", PFSTR(cmd));
 				//debug("Will use script %.*s to test %.*s\n",
 				//	PFSTR(cmd), PFSTR(name));
@@ -170,7 +168,6 @@ void GuessnetParser::parse(FILE* input, ScanConsumer& sc) throw (Exception)
 				sc.handleScan(new DHCPScan(name));
 				found++;
 			}
-#ifdef HAVE_PPPOE
 			else if (pppoe_line.match(line))
 			{
 				string name = script_line[1];
@@ -178,10 +175,9 @@ void GuessnetParser::parse(FILE* input, ScanConsumer& sc) throw (Exception)
 				//debug("Will use script %.*s to test %.*s\n",
 				//	PFSTR(cmd), PFSTR(name));
 
-				sc.handleScan(new ScriptScan(name, string(PPPOE " -I ") + Environment::get().iface() + " -A >/dev/null 2>&1"));
+				sc.handleScan(new ScriptScan(name, string("pppoe -I ") + Environment::get().iface() + " -A >/dev/null 2>&1"));
 				found++;
 			}
-#endif
 			else if (wireless_mac_essid_line.match(line))
 			{
 				string name = wireless_mac_essid_line[1];
