@@ -27,7 +27,7 @@
 class GuessnetParser
 {
 public:
-	static void parse(FILE* in, ScanConsumer& sc) throw (Exception);
+	static void parse(FILE* in, ScanConsumer& sc);
 };
 
 // vim:set ts=4 sw=4:
