@@ -28,14 +28,12 @@
 #endif
 
 #include "IfaceParser.h"
-#include "stringf.h"
-#include "Regexp.h"
+#include <wibble/regexp.h>
 #include "Environment.h"
 
 #include <map>
 
 using namespace std;
-using namespace stringf;
 
 class Tokenizer
 {
@@ -68,37 +66,36 @@ public:
  * parser.
  */
 void IfaceParser::parse(FILE* input, ScanConsumer& sc)
-	throw (Exception)
 {
 #define ATLINESTART "^[[:blank:]]*(guessnet[0-9]*[[:blank:]]+)?test[0-9]*(-|[[:blank:]]+)"
 #define MACPATTERN "[0-9A-Fa-f]{2}:[0-9A-Fa-f]{2}:[0-9A-Fa-f]{2}:[0-9A-Fa-f]{2}:[0-9A-Fa-f]{2}:[0-9A-Fa-f]{2}"
-	ExtendedRegexp null_line("^[[:blank:]]*(#.*)?$");
-	ExtendedRegexp iface_line(
+	wibble::ERegexp null_line("^[[:blank:]]*(#.*)?$");
+	wibble::ERegexp iface_line(
 		"^[[:blank:]]*iface[[:blank:]]+"
 		"([^[:blank:]]+)[[:blank:]]+"
 		"([^[:blank:]]+)[[:blank:]]+"
 		"([^[:blank:]]+)[[:blank:]]*$", 4);
-	ExtendedRegexp peer_line(
+	wibble::ERegexp peer_line(
 		ATLINESTART "peer[[:blank:]]+(.+)$", 4);
-	ExtendedRegexp cable_line(
+	wibble::ERegexp cable_line(
 		ATLINESTART "missing-cable[[:blank:]]*([[:blank:]]+.+)?$");
-	ExtendedRegexp script_line(
+	wibble::ERegexp script_line(
 		ATLINESTART "(script|command)[[:blank:]]+(.+)$", 5);
-	ExtendedRegexp dhcp_line(
+	wibble::ERegexp dhcp_line(
 		ATLINESTART "dhcp[[:blank:]]*([[:blank:]]+.+)?$");
-	ExtendedRegexp pppoe_line(
+	wibble::ERegexp pppoe_line(
 		ATLINESTART "pppoe[[:blank:]]*([[:blank:]]+.+)?$");
-	ExtendedRegexp wireless_mac_essid_line(
+	wibble::ERegexp wireless_mac_essid_line(
 		ATLINESTART "wireless[[:blank:]]+mac[[:blank:]]+([^[:blank:]]+)[[:blank:]]+essid[[:blank:]](.+)$", 5);
-	ExtendedRegexp wireless_mac_line(
+	wibble::ERegexp wireless_mac_line(
 		ATLINESTART "wireless[[:blank:]]+mac[[:blank:]]+([^[:blank:]]+)[[:blank:]]*$", 4);
-	ExtendedRegexp wireless_essid_line(
+	wibble::ERegexp wireless_essid_line(
 		ATLINESTART "wireless[[:blank:]]+essid[[:blank:]](.+)$", 4);
-	ExtendedRegexp old_default_line(
+	wibble::ERegexp old_default_line(
 		"^[[:blank:]]*guessnet[[:blank:]]+"
 		"default[[:blank:]]*$");
-	ExtendedRegexp generic_guessnet_line(ATLINESTART);
-	ExtendedRegexp parm_line(
+	wibble::ERegexp generic_guessnet_line(ATLINESTART);
+	wibble::ERegexp parm_line(
 		"^[[:blank:]]*([^[:blank:]]+)[[:blank:]]+(.+)$", 2);
 	string profileName;
 
@@ -225,16 +222,14 @@ void IfaceParser::parse(FILE* input, ScanConsumer& sc)
 					found++;
 				}
 			}
-#ifdef HAVE_PPPOE
 			else if (pppoe_line.match(line))
 			{
 				if (profileName.size())
 				{
-					sc.handleScan(new ScriptScan(profileName, string(PPPOE " -I ") + Environment::get().iface() + " -A >/dev/null 2>&1"));
+					sc.handleScan(new ScriptScan(profileName, string("pppoe -I ") + Environment::get().iface() + " -A >/dev/null 2>&1"));
 					found++;
 				}
 			}
-#endif
 			else if (wireless_mac_essid_line.match(line))
 			{
 				if (profileName.size())
