@@ -4,6 +4,7 @@ extern "C" {
 #include <libnet.h>
 }
 
+using namespace wibble::sys;
 
 static Buffer buffer_from_libnet(libnet_t* ln_context)
 {
@@ -60,7 +61,7 @@ Buffer PacketMaker::makeARPRequest(const IPAddress& ip, const IPAddress& src) th
 
 Buffer PacketMaker::makePingRequest(const ether_addr& mac, const IPAddress& src) throw ()
 {
-	unsigned char ether_broadcast_addr[6] = {0xff, 0xff, 0xff, 0xff, 0xff, 0xff};
+	//unsigned char ether_broadcast_addr[6] = {0xff, 0xff, 0xff, 0xff, 0xff, 0xff};
 	//unsigned char ether_no_addr[6] = {0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
 	struct libnet_ether_addr* localmac = sender.getMACAddress();
 	libnet_t* ln_context = sender.getLibnetContext();
@@ -95,7 +96,7 @@ Buffer PacketMaker::makePingRequest(const ether_addr& mac, const IPAddress& src)
 				0,			// payload len
 				ln_context,
 				0) == -1)
-		throw libnetException(ln_context, "Building ICMPv4 echo packet");
+		throw wibble::exception::Libnet(ln_context, "Building ICMPv4 echo packet");
 
 	if (libnet_build_ipv4(
 				LIBNET_IPV4_H + LIBNET_ICMPV4_ECHO_H + 0,
@@ -111,7 +112,7 @@ Buffer PacketMaker::makePingRequest(const ether_addr& mac, const IPAddress& src)
 				0,
 				ln_context,
 				0) == -1)
-		throw libnetException(ln_context, "Building IPv4 packet");
+		throw wibble::exception::Libnet(ln_context, "Building IPv4 packet");
 
 	if (libnet_build_ethernet(
 			(u_char*)&mac,
@@ -119,7 +120,7 @@ Buffer PacketMaker::makePingRequest(const ether_addr& mac, const IPAddress& src)
 			ETHERTYPE_IP,
 			NULL, 0,
 			ln_context, 0) == -1)
-		throw libnetException(ln_context, "Building Ethernet packet");
+		throw wibble::exception::Libnet(ln_context, "Building Ethernet packet");
 
 	// Construct the packet
 	return buffer_from_libnet(ln_context);
