@@ -19,24 +19,53 @@
  */
 
 #include "Parser.h"
-#include "stringf.h"
+#include <sstream>
+
+namespace wibble {
+namespace exception {
+
+static std::string parserContext(const std::string& file, int line) throw ()
+{
+	std::stringstream str;
+	if (line == -1)
+		str << "parsing file " << file;
+	else
+		str << file << ":" << line;
+	return str.str();
+}
+
+static std::string parserContext(int line) throw ()
+{
+	std::stringstream str;
+	str << "parsing line " << line;
+	return str.str();
+}
+
+Parser::Parser(const std::string& file, int line, const std::string& error) throw ()
+	: Consistency(parserContext(file, line), error), m_file(file), m_line(line) {}
+Parser::Parser(int line, const std::string& error) throw ()
+	: Consistency(parserContext(line), error), m_line(line) {}
+Parser::Parser(const std::string& context, const std::string& error) throw ()
+	: Consistency(context, error), m_line(-1) {}
+
+void Parser::setLocation(const std::string file, int line) throw ()
+{
+	m_file = file;
+	if (line != -1) m_line = line;
+	m_context[0] = parserContext(m_file, m_line);
+}
+
+void Parser::setLocation(int line) throw ()
+{
+	if (line != -1) m_line = line;
+	m_context[0] = parserContext(m_file, m_line);
+}
+
+}
+}
+
 
 using namespace std;
-using namespace stringf;
-
-string ParserException::desc() const throw ()
-{
-	if (_file.size() > 0)
-		if (_line != -1)
-			return _file + ":" + fmt(_line) + ": " + _context;
-		else
-			return _file + ":" + _context;
-	else
-		if (_line != -1)
-			return fmt(_line) + ": " + _context;
-		else
-			return _context;
-}
 
 string DefaultScan::signature() const throw ()
 {
