@@ -33,6 +33,7 @@ extern "C" {
 */
 
 using namespace std;
+using namespace wibble::sys;
 
 void PeerScanner::registerWith(NetWatcher& watcher) throw ()
 {
@@ -79,7 +80,7 @@ void PeerScanner::handleEthernet(const NetBuffer& pkt) throw ()
 		const PeerScan* scan = *i;
 		if (!scan->hasIP() && MAC_MATCHES(&scan->mac(), packet_header->ether_shost))
 		{
-			debug("Got reply from %.*s\n", PFSTR(fmt(scan->mac())));
+			debug("Got reply from %s\n", fmt(scan->mac()).c_str());
 			succeeded(*i);
 		}
 	}
@@ -97,7 +98,7 @@ void PeerScanner::handleARP(const NetBuffer& arp) throw ()
 		in_addr* ipv4_him = arp_get_sip(arp_header);
 		ether_addr* mac_him = arp_get_sha(arp_header);
 
-		debug("Got ARP reply from %.*s %.*s\n", PFSTR(fmt(IPAddress(*ipv4_him))), PFSTR(fmt(*mac_him)));
+		debug("Got ARP reply from %s %s\n", fmt(IPAddress(*ipv4_him)).c_str(), fmt(*mac_him).c_str());
 
 		//IPv4_FROM_LIBNET(ipv4_me, arp_header->ar_tpa);
 		//IPv4_FROM_ARP(ipv4_him, arp_header->ar_spa);
@@ -118,7 +119,8 @@ void PeerScanner::handleARP(const NetBuffer& arp) throw ()
 
 			if (match)
 			{
-				debug("ARP reply from %.*s %.*s matches\n", PFSTR(fmt(IPAddress(*ipv4_him))), PFSTR(fmt(*mac_him)));
+				debug("ARP reply from %s %s matches\n",
+						fmt(IPAddress(*ipv4_him)).c_str(), fmt(*mac_him).c_str());
 				succeeded(*i);
 			}
 		}
