@@ -4,7 +4,7 @@
 /*
  * Run test scripts in parallel
  *
- * Copyright (C) 2003  Enrico Zini <enrico@debian.org>
+ * Copyright (C) 2003--2006  Enrico Zini <enrico@debian.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "Exception.h"
+#include <wibble/exception.h>
 #include <string>
 
 class ProcessListener
@@ -44,14 +44,14 @@ protected:
 	ProcessRunnerImpl* impl;
 	
 public:
-	ProcessRunner() throw (SystemException);
+	ProcessRunner() throw (wibble::exception::System);
 	ProcessRunner(const ProcessRunner& f) throw ();
-	~ProcessRunner() throw (SystemException);
-	ProcessRunner& operator=(const ProcessRunner& f) throw (SystemException);
+	~ProcessRunner() throw (wibble::exception::System);
+	ProcessRunner& operator=(const ProcessRunner& f) throw (wibble::exception::System);
 
 	void addProcess(const std::string& tag, const std::string& cmdline, ProcessListener* pl) throw ();
 
-	void shutdown() throw (SystemException);
+	void shutdown() throw (wibble::exception::System);
 };
 
 // vim:set ts=4 sw=4:
