@@ -46,6 +46,8 @@ protected:
 	IPAddress _source;
 
 public:
+	PeerScan(const std::string& name) throw ();
+
 	PeerScan(const std::string& name, const ether_addr& mac, const IPAddress& ip) throw ()
 		: Scan(name), _mac(mac), _ip(ip), _source("0.0.0.0") {}
 
@@ -56,6 +58,14 @@ public:
 	const IPAddress& ip() const throw () { return _ip; }
 	const IPAddress& source() const throw () { return _source; }
 
+	void setMAC(const ether_addr& mac) { _mac = mac; }
+	void setIP(const IPAddress& ip) { _ip = ip; }
+	void setSource(const IPAddress& source) { _source = source; }
+
+	bool hasMAC() const;
+	bool hasIP() const { return _ip != IPAddress("0.0.0.0"); }
+	bool hasSource() const { return _source != IPAddress("0.0.0.0"); }
+
 	virtual std::string signature() const throw ();
 };
 
