@@ -1,7 +1,7 @@
 /*
  * Tester that delegates testing to an external script
  *
- * Copyright (C) 2003  Enrico Zini <enrico@debian.org>
+ * Copyright (C) 2003--2006  Enrico Zini <enrico@debian.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,14 +19,18 @@
  */
 
 #include "ScriptScanner.h"
+#include "Environment.h"
 
 using namespace std;
+using namespace wibble::sys;
 
 
 void ScriptScanner::handleTermination(const std::string& signature, int status) throw ()
 {
 	MutexLock lock(candMutex);
 
+	verbose("script [%s] terminated with status %d\n", signature.c_str(), status);
+
 	if (status != 0)
 		return;
 
@@ -43,6 +47,7 @@ void ScriptScanner::addCandidate(const ScriptScan* scan)
 	if (i == scans.end())
 	{
 		scans.insert(pair<string, const Scan*>(scan->signature(), scan));
+		verbose("adding candidate script [%s] with tag [%s]\n", scan->cmdline().c_str(), scan->signature().c_str());
 		runner.addProcess(scan->signature(), scan->cmdline(), this);
 	}
 }
