@@ -4,7 +4,7 @@
 /*
  * Tester that delegates testing to an external script
  *
- * Copyright (C) 2003  Enrico Zini <enrico@debian.org>
+ * Copyright (C) 2003--2006  Enrico Zini <enrico@debian.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "Mutex.h"
+#include <wibble/sys/mutex.h>
 #include "Scanner.h"
 #include "ProcessRunner.h"
 
@@ -32,7 +32,7 @@ class ScriptScanner : public Scanner, public ProcessListener
 {
 protected:
 	ProcessRunner runner;
-	Mutex candMutex;
+	wibble::sys::Mutex candMutex;
 	std::map<std::string, const Scan*> scans;
 
 public: 
