@@ -34,13 +34,14 @@
 #include "ScriptScanner.h"
 #include "DHCPScanner.h"
 #include "ScanConsumer.h"
-#include "Mutex.h"
 #include "GuessnetEnvironment.h"
 #include "ScanBag.h"
-#include "stringf.h"
 
 #include "IFace.h"
 
+#include <wibble/sys/mutex.h>
+#include <wibble/sys/thread.h>
+
 #include <stdio.h>
 #include <ctype.h>
 #include <errno.h>	/* errno */
@@ -53,14 +54,12 @@
 #include <unistd.h>     // close, geteuid
 #include <pwd.h>		// getpwuid
 
-
 #include <set>
 #include <vector>
-
-#include "Thread.h"
+#include <iostream>
 
 using namespace std;
-using namespace stringf;
+using namespace wibble::sys;
 
 class ScanRunner : public ScannerListener, public ScanConsumer
 {
@@ -94,8 +93,8 @@ public:
 			candidates = scanbag.notify(scan);
 			if (candidates.size() == 1)
 				waitCond.broadcast();
-		} catch (Exception& e) {
-			error("%s: %.*s\n", e.type(), PFSTR(e.desc()));
+		} catch (std::exception& e) {
+			error("%s\n", e.what());
 		}
 	}
 
@@ -143,7 +142,7 @@ class FakeScanner : public ScanRunner, Thread
 protected:
 	bool _canceled;
 	
-	virtual void* main() throw ()
+	virtual void* main()
 	{
 		interact();
 		return 0;
@@ -156,8 +155,8 @@ public:
 	bool canceled() const throw () { return _canceled; }
 	bool canceled(bool val) throw () { return _canceled = val; }
 	
-	void shutdown() throw (Exception) { canceled(true); }
-	void startScans() throw (SystemException, libnetException, pcapException)
+	void shutdown() { canceled(true); }
+	void startScans()
 	{
 		printf("Scans contents:\n");
 		scanbag.dump();
@@ -168,38 +167,38 @@ public:
 			const Scan* scan = *i;
 			if (const PeerScan* s = dynamic_cast<const PeerScan*>(scan))
 			{
-				debug("Will check network %.*s for IP address %.*s (MAC %.*s)\n",
-						PFSTR(s->name()), PFSTR(fmt(s->ip())), PFSTR(fmt(s->mac())));
+				debug("Will check network %s for IP address %s (MAC %s)\n",
+						s->name().c_str(), fmt(s->ip()).c_str(), fmt(s->mac()).c_str());
 				cand_count++;
 			}
 			else if (const LinkBeatScan* s = dynamic_cast<const LinkBeatScan*>(scan))
 			{
 				//warning("Link-beat detection currently disabled\n");
-				debug("Will test for link beat.  If absent, will return %.*s\n",
-						PFSTR(s->name()));
+				debug("Will test for link beat.  If absent, will return %s\n",
+						s->name().c_str());
 				cand_count++;
 			}
 			else if (const ScriptScan* s = dynamic_cast<const ScriptScan*>(scan))
 			{
-				debug("Will use command '%.*s' to test %.*s\n",
-						PFSTR(s->cmdline()), PFSTR(s->name()));
+				debug("Will use command '%s' to test %s\n",
+						s->cmdline().c_str(), s->name().c_str());
 				cand_count++;
 			}
 			if (const DHCPScan* s = dynamic_cast<const DHCPScan*>(scan))
 			{
-				debug("Will check network %.*s for DHCP service\n",
-						PFSTR(s->name()));
+				debug("Will check network %s for DHCP service\n",
+						s->name().c_str());
 				cand_count++;
 			}
 			else if (const DefaultScan* s = dynamic_cast<const DefaultScan*>(scan))
 			{
-				debug("Default test is %.*s\n",
-						PFSTR(s->name()));
+				debug("Default test is %s\n",
+						s->name().c_str());
 				cand_count++;
 			}
 			else
 				//printf("Unknown test %p\n", scan);
-				printf("Unknown test %.*s: %.*s\n", PFSTR(scan->name()), PFSTR(scan->signature()));
+				printf("Unknown test %s: %s\n", scan->name().c_str(), scan->signature().c_str());
 		}
 
 		start();
@@ -216,11 +215,9 @@ public:
 			const list<const Scan*>& cands = scanbag.getScans();
 			for (list<const Scan*>::const_iterator i = cands.begin();
 					i != cands.end(); i++)
-			{
-				printf("%2d: %.*s (%.*s)\n", num++, PFSTR((*i)->name()), PFSTR((*i)->signature()));
-			}
-			printf(" 0: quit\n");
-			printf("> ");
+				cout << num++ << ": " << (*i)->name() << " (" << (*i)->signature() << ")" << endl;
+			cout << " 0: quit" << endl;
+			cout << "> ";
 			unsigned int res;
 			fscanf(in, "%d", &res);
 			if (res == 0)
@@ -247,12 +244,12 @@ protected:
 	ProcessRunner* runner;
 
 	PeerScanner* peerScanner;
-	ScriptScanner* scriptScanner;
 	DHCPScanner* dhcpScanner;
+	ScriptScanner* scriptScanner;
 
 	IFace& iface;
 
-	void startNetScanning() throw (SystemException, libnetException, pcapException)
+	void startNetScanning()
 	{
 		if (!sender)
 			sender = new NetSender(GuessnetEnvironment::get().iface());
@@ -260,7 +257,7 @@ protected:
 			watcher = new NetWatcher(GuessnetEnvironment::get().iface());
 	}
 
-	void startPeerScanner() throw (SystemException, libnetException, pcapException)
+	void startPeerScanner()
 	{
 		if (peerScanner)
 			return;
@@ -269,7 +266,7 @@ protected:
 		peerScanner = new PeerScanner(*sender, this);
 	}
 
-	void startScriptScanner() throw (SystemException)
+	void startScriptScanner()
 	{
 		if (scriptScanner)
 			return;
@@ -278,7 +275,7 @@ protected:
 		scriptScanner = new ScriptScanner(*runner, this);
 	}
 
-	void startDHCPScanner() throw (SystemException, libnetException, pcapException)
+	void startDHCPScanner()
 	{
 		if (dhcpScanner)
 			return;
@@ -288,11 +285,11 @@ protected:
 	}
 
 public:
-	MainScanner(IFace& iface) throw (Exception) : ScanRunner(),
+	MainScanner(IFace& iface) : ScanRunner(),
 		sender(0), watcher(0), runner(0), peerScanner(0), dhcpScanner(0), scriptScanner(0),
 		iface(iface) {}
 
-	void shutdown() throw (Exception)
+	void shutdown()
 	{
 		if (watcher)
 			watcher->shutdown();
@@ -300,7 +297,7 @@ public:
 			runner->shutdown();
 	}
 	
-	void startScans() throw (SystemException, libnetException, pcapException)
+	void startScans()
 	{
 		for (list<const Scan*>::const_iterator i = scanbag.getScans().begin();
 				i != scanbag.getScans().end(); i++)
@@ -308,8 +305,8 @@ public:
 			const Scan* scan = *i;
 			if (const PeerScan* s = dynamic_cast<const PeerScan*>(scan))
 			{
-				debug("Will check network %.*s for IP address %.*s (MAC %.*s)\n",
-						PFSTR(s->name()), PFSTR(fmt(s->ip())), PFSTR(fmt(s->mac())));
+				debug("Will check network %s for IP address %s (MAC %s)\n",
+						s->name().c_str(), fmt(s->ip()).c_str(), fmt(s->mac()).c_str());
 
 				startPeerScanner();
 				peerScanner->addCandidate(s);
@@ -319,13 +316,13 @@ public:
 			else if (const LinkBeatScan* s = dynamic_cast<const LinkBeatScan*>(scan))
 			{
 				//warning("Link-beat detection currently disabled\n");
-				debug("Will test for link beat.  If absent, will return %.*s\n",
-						PFSTR(s->name()));
+				debug("Will test for link beat.  If absent, will return %s\n",
+						s->name().c_str());
 
 				iface.update();
 				if (!iface.has_mii())
-					warning("Link beat test requested on an interface without link beat detection support\n");
-				if (!iface.connected())
+					warning("Link beat test requested on an interface without link beat detection support: assuming we are always connected\n");
+				else if (!iface.connected())
 				{
 					verbose("Link beat not detected\n");
 					notifyScan(s);
@@ -335,8 +332,8 @@ public:
 			}
 			else if (const ScriptScan* s = dynamic_cast<const ScriptScan*>(scan))
 			{
-				debug("Will use command '%.*s' to test %.*s\n",
-						PFSTR(s->cmdline()), PFSTR(s->name()));
+				debug("Will use command '%s' to test %s\n",
+						s->cmdline().c_str(), s->name().c_str());
 
 				startScriptScanner();
 				scriptScanner->addCandidate(s);
@@ -345,8 +342,8 @@ public:
 			}
 			else if (const DHCPScan* s = dynamic_cast<const DHCPScan*>(scan))
 			{
-				debug("Will check network %.*s for DHCP service\n",
-						PFSTR(s->name()));
+				debug("Will check network %s for DHCP service\n",
+						s->name().c_str());
 
 				startDHCPScanner();
 				dhcpScanner->addCandidate(s);
@@ -355,13 +352,12 @@ public:
 			}
 			else if (const DefaultScan* s = dynamic_cast<const DefaultScan*>(scan))
 			{
-				debug("Default test is %.*s\n",
-						PFSTR(s->name()));
+				debug("Default test is %s\n", s->name().c_str());
 				cand_count++;
 			}
 			else
 				//printf("Unknown test %p\n", scan);
-				printf("Unknown test %.*s: %.*s\n", PFSTR(scan->name()), PFSTR(scan->signature()));
+				printf("Unknown test %s: %s\n", scan->name().c_str(), scan->signature().c_str());
 		}
 
 		if (peerScanner)
@@ -394,7 +390,7 @@ bool detectIfupdown()
 int main (int argc, const char *argv[])
 {
 	// Install the handler for unexpected exceptions
-	InstallUnexpected installUnexpected;
+	wibble::exception::InstallUnexpected installUnexpected;
 
 	// Access the interface
 	try {
@@ -418,7 +414,7 @@ int main (int argc, const char *argv[])
 			iface_was_down = !iface.up();
 			if (iface_was_down)
 			{
-				verbose("Interface %.*s was down: initializing for broadcast\n", PFSTR(iface.name()));
+				verbose("Interface %s was down: initializing for broadcast\n", iface.name().c_str());
 				saved_iface_cfg = iface.initBroadcast(GuessnetEnvironment::get().initTimeout());
 			}
 
@@ -445,7 +441,7 @@ int main (int argc, const char *argv[])
 			debug("Initialized test subsystems\n");
 
 			scanner.handleScan(new DefaultScan(GuessnetEnvironment::get().defprof()));
-			debug("Added \"default\" test %.*s\n", PFSTR(GuessnetEnvironment::get().defprof()));
+			debug("Added \"default\" test %s\n", GuessnetEnvironment::get().defprof().c_str());
 
 			for (vector<const Scan*>::const_iterator i = scans.begin(); i != scans.end(); i++)
 				scanner.handleScan(*i);
@@ -472,12 +468,12 @@ int main (int argc, const char *argv[])
 			// Output the profile name we found
 			if (profile.size())
 			{
-				printf("%.*s\n", PFSTR(profile));
+				cout << profile << endl;
 			} else {
-				printf("%.*s\n", PFSTR(GuessnetEnvironment::get().defprof()));
+				cout << GuessnetEnvironment::get().defprof() << endl;
 			}
-		} catch (Exception& e) {
-			error("%s: %.*s\n", e.type(), PFSTR(e.desc()));
+		} catch (std::exception& e) {
+			error("%s\n", e.what());
 			if (geteuid() != 0)
 			{
 				struct passwd *p = getpwuid(geteuid());
@@ -490,8 +486,8 @@ int main (int argc, const char *argv[])
 		if (iface_was_down)
 			iface.setConfiguration(saved_iface_cfg);
 
-	} catch (Exception& e) {
-		error("%s: %.*s\n", e.type(), PFSTR(e.desc()));
+	} catch (std::exception& e) {
+		error("%s\n", e.what());
 		if (geteuid() != 0)
 		{
 			struct passwd *p = getpwuid(geteuid());
