@@ -6,7 +6,7 @@
 static void printConfig(const char* tag, IFace& iface)
 {
 	if_params ifp = iface.getConfiguration();
-	printf("%-10.10s %.*s: ", tag, PFSTR(iface.name()));
+	printf("%-10.10s %s: ", tag, iface.name().c_str());
 	ifp.print();
 }
 
@@ -27,21 +27,21 @@ int main(int argc, char* argv[])
 		printConfig("Down", iface);
 		fprintf(stderr, "\t\tConfiguring for broadcast...\n");
 		if_params unconf = iface.initBroadcast(4);
-		printf("%-10.10s %.*s: ", "Pre-Bcast", PFSTR(iface.name()));
+		printf("%-10.10s %s: ", "Pre-Bcast", iface.name().c_str());
 		unconf.print();
 		printConfig("Broadcast", iface);
 		fprintf(stderr, "\t\tIfconfig for broadcast...\n");
 		system("ifconfig");
 		fprintf(stderr, "\t\tReconfiguring interface...\n");
 		if_params bcast = iface.setConfiguration(ifp);
-		printf("%-10.10s %.*s: ", "Pre-Restore", PFSTR(iface.name()));
+		printf("%-10.10s %s: ", "Pre-Restore", iface.name().c_str());
 		bcast.print();
 		printConfig("Restored", iface);
 		fprintf(stderr, "\t\tDone.\n");
 	}
-	catch (Exception& e)
+	catch (std::exception& e)
 	{
-		error("%s: %.*s\n", e.type(), PFSTR(e.desc()));
+		error("%s\n", e.what());
 		return 1;
 	}
 	return 0;
