@@ -6,18 +6,21 @@
 
 #include <stdio.h>
 
+#include <iostream>
+
 extern "C" {
 #include <libnet.h>
 }
 
 using namespace std;
+using namespace wibble::sys;
 
 class PacketPrinter : public PacketListener
 {
 public:
 	virtual void handleARP(struct libnet_arp_hdr* arp_header) throw ()
 	{
-		printf("Seen ARP");
+		cout << "Seen ARP";
 
 		// Parse and check the arp header
 		if (ntohs (arp_header->ar_op) == ARPOP_REPLY)
@@ -29,16 +32,16 @@ public:
 
 			rep += fmt(IPAddress(*ipv4_him)) + " " + fmt(*mac_him);
 
-			printf(" reply from %.*s", PFSTR(rep));
+			cout << " reply from " << rep;
 
 			//IPv4_FROM_LIBNET(ipv4_me, arp_header->ar_tpa);
 			//IPv4_FROM_ARP(ipv4_him, arp_header->ar_spa);
 		}
-		printf("\n");
+		cout << endl;
 	}
 	virtual void handleEthernet(struct libnet_ethernet_hdr* arp_header) throw ()
 	{
-		printf("Seen Ethernet\n");
+		cout << "Seen Ethernet" << endl;
 	}
 // others to come as needed, like:
 // //         // virtual handleDHCP(struct libnet_hdcp_something* hdcp_header) throw () {}
@@ -47,7 +50,7 @@ public:
 static void printConfig(const char* tag, IFace& iface)
 {
 	if_params ifp = iface.getConfiguration();
-	printf("%-10.10s %.*s: ", tag, PFSTR(iface.name()));
+	printf("%-10.10s %s: ", tag, iface.name().c_str());
 	ifp.print();
 }
 
@@ -56,14 +59,14 @@ int main(int argc, char* argv[])
 	if (argc < 2)
 		fatal_error("Usage: %s <iface>\n", argv[0]);
 	try {
-		InstallUnexpected installUnexpected;
+		wibble::exception::InstallUnexpected installUnexpected;
 
 		{
 			fprintf(stderr, "\t\tTrying libnet setup...\n");
 			libnet_t* ln_context;
 			char ln_errbuf[LIBNET_ERRBUF_SIZE];
 			if (!(ln_context = libnet_init(LIBNET_LINK_ADV, argv[1], ln_errbuf)))
-				throw libnetException(ln_errbuf, "opening link interface");
+				throw wibble::exception::Libnet(ln_errbuf, "opening link interface");
 			fprintf(stderr, "\t\tLibnet deleting %p...\n", ln_context);
 			libnet_destroy(ln_context);
 			fprintf(stderr, "\t\tLibnet tried...\n");
@@ -121,9 +124,9 @@ int main(int argc, char* argv[])
 		printConfig("Restored", iface);
 		fprintf(stderr, "\t\tDone.\n");
 	}
-	catch (Exception& e)
+	catch (std::exception& e)
 	{
-		error("%s: %.*s\n", e.type(), PFSTR(e.desc()));
+		error("%s\n", e.what());
 		return 1;
 	}
 	return 0;
