@@ -2,17 +2,19 @@
 #include "ProcessRunner.h"
 
 #include <stdio.h>
+#include <iostream>
 
 #define DEBUG(args...) fprintf(stderr, ##args)
 //#define DEBUG(args...) do {} while(0)
 
+using namespace std;
 
 class ProcessPrinter : public ProcessListener
 {
 public:
 	virtual void handleTermination(const std::string& tag, int status) throw ()
 	{
-		printf("%.*s: terminated with status %d\n", PFSTR(tag), status);
+		cout << tag << ": terminated with status " << status << endl;
 	}
 };
 
@@ -20,7 +22,7 @@ public:
 int main(int argc, char* argv[])
 {
 	try {
-		InstallUnexpected installUnexpected;
+		wibble::exception::InstallUnexpected installUnexpected;
 
 		Environment::get().debug(true);
 
@@ -50,9 +52,9 @@ int main(int argc, char* argv[])
 
 		fprintf(stderr, "\t\tDone.\n");
 	}
-	catch (Exception& e)
+	catch (std::exception& e)
 	{
-		error("%s: %.*s\n", e.type(), PFSTR(e.desc()));
+		error("%s", e.what());
 		return 1;
 	}
 	return 0;
